## Explainer

This plot is modified from the approach of [warming stripes](https://en.wikipedia.org/wiki/Warming_stripes) showing the difference in monthly and annual data. On the x-axis we see the months. On the y-axis are years in decending order. The colour values correspond to the difference to the mean in the the reference period.

Since the plot shows the anomaly of the data against some reference period, this period can be selected manually. Depending on the chosen reference, the picture changes. However, one should keep in mind that the scientific community currently expects that effects of climate change slipped from the "normal" range of weather stochasticity around the year 2000.

Since the climate projections consist of multiple climate model outputs, the period after 2006 appears much smoother than the actual weather records. Please head over to the chaper "Climate Projections" for more details.